@@ -1,32 +1,28 @@
-# -*- coding: utf-8 -*-
-## src/tooltips.py
-##
-## Copyright (C) 2005 Alex Mauer <hawke AT hawkesnest.net>
-##                    Stéphan Kochen <stephan AT kochen.nl>
-## Copyright (C) 2005-2006 Dimitur Kirov <dkirov AT gmail.com>
-## Copyright (C) 2005-2007 Nikos Kouremenos <kourem AT gmail.com>
-## Copyright (C) 2005-2014 Yann Leboulanger <asterix AT lagaule.org>
-## Copyright (C) 2006 Travis Shirk <travis AT pobox.com>
-##                    Stefan Bethge <stefan AT lanpartei.de>
-## Copyright (C) 2006-2007 Jean-Marie Traissard <jim AT lapin.org>
-## Copyright (C) 2007 Julien Pivotto <roidelapluie AT gmail.com>
-## Copyright (C) 2007-2008 Stephan Erb <steve-e AT h3c.de>
-## Copyright (C) 2008 Jonathan Schleifer <js-gajim AT webkeks.org>
-##
-## This file is part of Gajim.
-##
-## Gajim is free software; you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published
-## by the Free Software Foundation; version 3 only.
-##
-## Gajim is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-## GNU General Public License for more details.
-##
-## You should have received a copy of the GNU General Public License
-## along with Gajim. If not, see <http://www.gnu.org/licenses/>.
-##
+# Copyright (C) 2005 Alex Mauer <hawke AT hawkesnest.net>
+#                    Stéphan Kochen <stephan AT kochen.nl>
+# Copyright (C) 2005-2006 Dimitur Kirov <dkirov AT gmail.com>
+# Copyright (C) 2005-2007 Nikos Kouremenos <kourem AT gmail.com>
+# Copyright (C) 2005-2014 Yann Leboulanger <asterix AT lagaule.org>
+# Copyright (C) 2006 Travis Shirk <travis AT pobox.com>
+#                    Stefan Bethge <stefan AT lanpartei.de>
+# Copyright (C) 2006-2007 Jean-Marie Traissard <jim AT lapin.org>
+# Copyright (C) 2007 Julien Pivotto <roidelapluie AT gmail.com>
+# Copyright (C) 2007-2008 Stephan Erb <steve-e AT h3c.de>
+# Copyright (C) 2008 Jonathan Schleifer <js-gajim AT webkeks.org>
+#
+# This file is part of Gajim.
+#
+# Gajim is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published
+# by the Free Software Foundation; version 3 only.
+#
+# Gajim is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Gajim. If not, see <http://www.gnu.org/licenses/>.
 
 import os
 import time
@@ -43,6 +39,7 @@ from gajim.common.const import AvatarSize
 from gajim.common import app
 from gajim.common import helpers
 from gajim.common.i18n import Q_
+from gajim.common.i18n import _
 
 log = logging.getLogger('gajim.tooltips')
 
@@ -143,19 +140,17 @@ class NotificationAreaTooltip(StatusTable):
             message = acct['message']
             message = helpers.reduce_chars_newlines(message, 100, 1)
             message = GLib.markup_escape_text(message)
-            if acct['name'] in app.con_types and \
-                    app.con_types[acct['name']] in ('tls', 'ssl'):
-                show_lock = True
-            else:
-                show_lock = False
+            con_type = app.con_types.get(acct['name'])
+            show_lock = con_type in ('tls', 'ssl')
+
             if message:
                 self.add_status_row(file_path, acct['show'],
-                    GLib.markup_escape_text(acct['account_label']) + ' - ' + message,
-                    show_lock=show_lock, indent=False)
+                    GLib.markup_escape_text(acct['account_label']) + ' - ' + \
+                    message, show_lock=show_lock, indent=False)
             else:
                 self.add_status_row(file_path, acct['show'],
-                    GLib.markup_escape_text(acct['account_label']), show_lock=show_lock,
-                    indent=False)
+                    GLib.markup_escape_text(acct['account_label']),
+                    show_lock=show_lock, indent=False)
             for line in acct['event_lines']:
                 self.add_text_row('  ' + line, 1)
 
@@ -326,19 +321,17 @@ class RosterTooltip(Gtk.Window, StatusTable):
             message = acct['message']
             message = helpers.reduce_chars_newlines(message, 100, 1)
             message = GLib.markup_escape_text(message)
-            if acct['name'] in app.con_types and \
-                    app.con_types[acct['name']] in ('tls', 'ssl'):
-                show_lock = True
-            else:
-                show_lock = False
+            con_type = app.con_types.get(acct['name'])
+            show_lock = con_type in ('tls', 'ssl')
+
             if message:
                 self.add_status_row(file_path, acct['show'],
-                    GLib.markup_escape_text(acct['name']) + ' - ' + message,
-                    show_lock=show_lock, indent=False)
+                    GLib.markup_escape_text(acct['account_label']) + ' - ' + \
+                    message, show_lock=show_lock, indent=False)
             else:
                 self.add_status_row(file_path, acct['show'],
-                    GLib.markup_escape_text(acct['name']), show_lock=show_lock,
-                    indent=False)
+                    GLib.markup_escape_text(acct['account_label']),
+                    show_lock=show_lock, indent=False)
             for line in acct['event_lines']:
                 self.add_text_row('  ' + line, 1)
 
@@ -371,7 +364,7 @@ class RosterTooltip(Gtk.Window, StatusTable):
             nbr_on, nbr_total = app.\
                 contacts.get_nb_online_total_contacts(
                 accounts=[account])
-            account_name = account
+            account_name = app.get_account_label(account)
             if app.account_is_connected(account):
                 account_name += ' (%s/%s)' % (repr(nbr_on),
                     repr(nbr_total))
@@ -384,34 +377,6 @@ class RosterTooltip(Gtk.Window, StatusTable):
                 contact.keyID = app.config.get_per('accounts',
                     connection.name, 'keyid')
             contacts.append(contact)
-            # if we're online ...
-            if connection.connection:
-                roster = connection.connection.getRoster()
-                # in threadless connection when no roster stanza is sent
-                # 'roster' is None
-                if roster and roster.getItem(jid):
-                    resources = roster.getResources(jid)
-                    # ...get the contact info for our other online
-                    # resources
-                    for resource in resources:
-                        # Check if we already have this resource
-                        found = False
-                        for contact_ in contacts:
-                            if contact_.resource == resource:
-                                found = True
-                                break
-                        if found:
-                            continue
-                        show = roster.getShow(jid + '/' + resource)
-                        if not show:
-                            show = 'online'
-                        contact = app.contacts.create_self_contact(
-                            jid=jid, account=account, show=show,
-                            status=roster.getStatus(
-                            jid + '/' + resource),
-                            priority=roster.getPriority(
-                            jid + '/' + resource), resource=resource)
-                        contacts.append(contact)
 
         # Username/Account/Groupchat
         self.prim_contact = app.contacts.get_highest_prio_contact_from_contacts(
@@ -502,7 +467,7 @@ class RosterTooltip(Gtk.Window, StatusTable):
         self.jid.show()
         self.jid_label.show()
 
-        # contact has only one ressource
+        # contact has only one resource
         if self.num_resources == 1 and contact.resource:
             res = GLib.markup_escape_text(contact.resource)
             prio = str(contact.priority)
@@ -560,25 +525,25 @@ class RosterTooltip(Gtk.Window, StatusTable):
         to the given property list.
         """
         if 'mood' in contact.pep:
-            mood = contact.pep['mood'].asMarkupText()
+            mood = contact.pep['mood'].as_markup_text()
             self.mood.set_markup(mood)
             self.mood.show()
             self.mood_label.show()
 
         if 'activity' in contact.pep:
-            activity = contact.pep['activity'].asMarkupText()
+            activity = contact.pep['activity'].as_markup_text()
             self.activity.set_markup(activity)
             self.activity.show()
             self.activity_label.show()
 
         if 'tune' in contact.pep:
-            tune = contact.pep['tune'].asMarkupText()
+            tune = contact.pep['tune'].as_markup_text()
             self.tune.set_markup(tune)
             self.tune.show()
             self.tune_label.show()
 
-        if 'location' in contact.pep:
-            location = contact.pep['location'].asMarkupText()
+        if 'geoloc' in contact.pep:
+            location = contact.pep['geoloc'].as_markup_text()
             self.location.set_markup(location)
             self.location.show()
             self.location_label.show()
@@ -615,14 +580,14 @@ class RosterTooltip(Gtk.Window, StatusTable):
 
     def _get_icon_name_for_tooltip(self, contact):
         """
-        Helper function used for tooltip contacts/acounts
+        Helper function used for tooltip contacts/accounts
 
         Tooltip on account has fake contact with sub == '', in this case we show
         real status of the account
         """
         if contact.ask == 'subscribe':
             return 'requested'
-        elif contact.sub in ('both', 'to', ''):
+        if contact.sub in ('both', 'to', ''):
             return contact.show
         return 'not in roster'
 
